@@ -3,13 +3,15 @@ Main interface for imagebuilder service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.imagebuilder import ImagebuilderClient
+    from mypy_boto3_imagebuilder import ImagebuilderClient
 
     session = boto3.Session()
 
     client: ImagebuilderClient = boto3.client("imagebuilder")
     session_client: ImagebuilderClient = session.client("imagebuilder")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
